package entities

import (
	"devops/util/dts"
	"time"
)

// Project 项目
type Project struct {
	// 项目编号，推荐使用 ObjectId 算法生成，也可以使用 UUID/NanoID 等。
	ID string `json:"id" gorm:"primaryKey"`
	// 项目名称
	Name string `json:"name" gorm:"unique"`
	// 项目别称，显示使用
	Alias string `json:"alias" gorm:"unique"`
	// 项目介绍
	Intro string `json:"intro"`
	// 项目网站
	Website string `json:"website"`
	// 项目的仓库地址，比如 GitHub、Gitee、Gitlab、Gitea 或自建的仓库，
	// 如果是私有仓库，应该携带授权信息（建议使用私有令牌而不是账号密码）。
	RepositoryURL string `json:"repositoryURL"`
	// 用于构建的仓库分支，若置空则使用主分支
	Branch string `json:"branch"`
	// 创建项目的用户编号
	CreatedBy uint `json:"createdBy"`
	// 创建项目时的时间
	CreatedAt time.Time `json:"createdAt"`
	// 上一次修改项目信息的用户编号
	UpdatedBy dts.NullUint `json:"updatedBy"`
	// 上一次修改项目信息的时间
	UpdatedAt dts.NullTime `json:"updatedAt" gorm:"autoUpdateTime:false"`
}
